@@ -756,8 +756,7 @@ levent_iface_subscribe(struct lldpd *cfg, int socket)
 {
 	log_debug("event", "subscribe to interface changes from socket %d",
 	    socket);
-	if (cfg->g_iface_cb == NULL)
-		levent_make_socket_nonblocking(socket);
+	levent_make_socket_nonblocking(socket);
 	cfg->g_iface_event = event_new(cfg->g_base, socket,
 	    EV_READ | EV_PERSIST, levent_iface_recv, cfg);
 	if (cfg->g_iface_event == NULL) {
@@ -914,3 +913,29 @@ levent_make_socket_blocking(int fd)
 	}
 	return 0;
 }
+
+#ifdef HOST_OS_LINUX
+/* Receive and log error from a socket when there is suspicion of an error. */
+void
+levent_recv_error(int fd, const char *source)
+{
+	do {
+		ssize_t n;
+		char buf[1024] = {};
+		struct msghdr msg = {
+			.msg_control = buf,
+			.msg_controllen = sizeof(buf)
+		};
+		if ((n = recvmsg(fd, &msg, MSG_ERRQUEUE | MSG_DONTWAIT)) <= 0) {
+			return;
+		}
+		struct cmsghdr *cmsg = CMSG_FIRSTHDR(&msg);
+		if (cmsg == NULL)
+			log_warnx("event", "received unknown error on %s",
+			    source);
+		else
+			log_warnx("event", "received error (level=%d/type=%d) on %s",
+			    cmsg->cmsg_level, cmsg->cmsg_type, source);
+	} while (1);
+}
+#endif
