@@ -244,6 +244,8 @@ _lldpctl_atom_get_int_config(lldpctl_atom_t *atom, lldpctl_key_t key)
 #endif
 	case lldpctl_k_config_tx_hold:
 		return c->config->c_tx_hold;
+	case lldpctl_k_config_max_neighbors:
+		return c->config->c_max_neighbors;
 	default:
 		return SET_ERROR(atom->conn, LLDPCTL_ERR_NOT_EXIST);
 	}
@@ -292,6 +294,10 @@ _lldpctl_atom_set_int_config(lldpctl_atom_t *atom, lldpctl_key_t key,
 		config.c_tx_hold = value;
 		if (value > 0) c->config->c_tx_hold = value;
 		break;
+	case lldpctl_k_config_max_neighbors:
+		config.c_max_neighbors = value;
+		if (value > 0) c->config->c_max_neighbors = value;
+		break;
 	case lldpctl_k_config_bond_slave_src_mac_type:
 		config.c_bond_slave_src_mac_type = value;
 		c->config->c_bond_slave_src_mac_type = value;
