@@ -489,6 +489,9 @@ typedef void (*lldpctl_change_callback)(lldpctl_conn_t *conn,
  * This function will register the necessity to push neighbor changes to lldpd
  * and therefore will issue IO operations. The error code could then be @c
  * LLDPCTL_ERR_WOULDBLOCK.
+ *
+ * Once a callback is registered, the connection shouldn't be used for anything
+ * else than receiving notifications.
  */
 int lldpctl_watch_callback(lldpctl_conn_t *conn,
     lldpctl_change_callback cb,
@@ -658,13 +661,15 @@ typedef enum {
 	lldpctl_k_config_hostname,	/**< `(S,WON)` System name overridden */
 	lldpctl_k_config_advertise_version, /**< `(I)` Advertise version */
 	lldpctl_k_config_lldpmed_noinventory, /**< `(I)` Disable LLDP-MED inventory */
-	lldpctl_k_config_paused,	      /**< `(I)` lldpd is paused */
+	lldpctl_k_config_paused,	      /**< `(I,WO)` lldpd is paused */
 	lldpctl_k_config_fast_start_enabled, /**< `(I,WO)` Is fast start enabled */
 	lldpctl_k_config_fast_start_interval, /**< `(I,WO)` Start fast transmit interval */
 	lldpctl_k_config_ifdescr_update, /**< `(I,WO)` Enable or disable setting interface description */
 	lldpctl_k_config_iface_promisc,  /**< `(I,WO)` Enable or disable promiscuous mode on interfaces */
 	lldpctl_k_config_chassis_cap_advertise, /**< `(I,WO)` Enable or disable chassis capabilities advertisement */
 	lldpctl_k_config_chassis_mgmt_advertise, /**< `(I,WO)` Enable or disable management addresses advertisement */
+	lldpctl_k_config_cid_string,    /**< `(S,WON)` User defined string for the chassis ID */
+	lldpctl_k_config_perm_iface_pattern, /**< `(S,WON)` Pattern of permanent interfaces */
 
 	lldpctl_k_interface_name = 1000, /**< `(S)` The interface name. */
 
@@ -684,6 +689,7 @@ typedef enum {
 	lldpctl_k_port_hidden,	   /**< `(I)` Is this port hidden (or should it be displayed?)? */
 	lldpctl_k_port_status,	   /**< `(IS,WO)` Operational status of this (local) port */
 	lldpctl_k_port_chassis,	   /**< `(A)` Chassis associated to the port */
+	lldpctl_k_port_ttl,        /**< `(I)` TTL for port, 0 if info is attached to chassis */
 
 	lldpctl_k_port_dot3_mfs = 1300,	   /**< `(I)` MFS */
 	lldpctl_k_port_dot3_aggregid,   /**< `(I)` Port aggregation ID */
@@ -725,6 +731,7 @@ typedef enum {
 	lldpctl_k_chassis_cap_available, /**< `(I)` Available capabalities (see `LLDP_CAP_*`) */
 	lldpctl_k_chassis_cap_enabled,	 /**< `(I)` Enabled capabilities (see `LLDP_CAP_*`) */
 	lldpctl_k_chassis_mgmt,		 /**< `(AL)` List of management addresses */
+	lldpctl_k_chassis_ttl,		 /**< Deprecated */
 
 	lldpctl_k_chassis_med_type = 1900, /**< `(IS)` Chassis MED type. See `LLDP_MED_CLASS_*` */
 	lldpctl_k_chassis_med_cap,  /**< `(I)` Available MED capabilitied. See `LLDP_MED_CAP_*` */
@@ -782,6 +789,8 @@ typedef enum {
 	lldpctl_k_config_tx_hold, /**< `(I,WO)` Transmit hold interval. */
 	lldpctl_k_config_bond_slave_src_mac_type, /**< `(I,WO)` bond slave src mac type. */
 	lldpctl_k_config_lldp_portid_type, /**< `(I,WO)` LLDP PortID TLV Subtype */
+	lldpctl_k_config_lldp_agent_type, /**< `(I,WO)` LLDP agent type */
+	lldpctl_k_config_max_neighbors, /**< `(I,WO)`Maximum number of neighbors per port. */
 
 	lldpctl_k_custom_tlvs = 5000,		/**< `(AL)` custom TLVs */
 	lldpctl_k_custom_tlvs_clear,		/** `(I,WO)` clear list of custom TLVs */
@@ -1027,10 +1036,10 @@ lldpctl_atom_t *lldpctl_atom_iter_value(lldpctl_atom_t *atom, lldpctl_atom_iter_
  * reference count of the provided value is decremented. If you need to use it
  * outside of the loop, you need to increment it.
  */
-#define lldpctl_atom_foreach(atom, value)				\
-	for (lldpctl_atom_iter_t *iter = lldpctl_atom_iter(atom);	\
-	     iter && (value = lldpctl_atom_iter_value(atom, iter));	\
-	     iter = lldpctl_atom_iter_next(atom, iter),			\
+#define lldpctl_atom_foreach(atom, value)						\
+	for (lldpctl_atom_iter_t *iter##_LINE_ = lldpctl_atom_iter(atom);		\
+	     iter##_LINE_ && (value = lldpctl_atom_iter_value(atom, iter##_LINE_));	\
+	     iter##_LINE_ = lldpctl_atom_iter_next(atom, iter##_LINE_),			\
 		 lldpctl_atom_dec_ref(value))
 
 /**
